# Attributes Metadata

The JSON files in this directory contain metadata about the various attributes that can be set with osxmetadata. The data is generated by [macos_mditem_metadata](https://github.com/RhetTbull/macos_mditem_metadata) and is loaded by osxmetadata when the module is importedsss